@@ -1,6 +1,6 @@
 # Test file for registry::entry dependencies
 # Syntax:
-# tclsh depends.tcl <Pextlib name>
+# tclsh depends.tcl registry.dylib
 
 proc main {pextlibname} {
     load $pextlibname
@@ -82,7 +82,7 @@ proc main {pextlibname} {
         test_set {[$g dependencies]} {}
     }
 
-    file delete test.db
+    file delete -force test.db test.db-shm test.db-wal
 }
 
 source tests/common.tcl
